==> types_boto3_full-1.35.74-py3-none-any.whl: types_boto3_route53_recovery_cluster/paginator.py <==
"""
Type annotations for route53-recovery-cluster service client paginators.

[Open documentation](https://youtype.github.io/types_boto3_docs/types_boto3_route53_recovery_cluster/paginators/)

Usage::

    ```python
    from boto3.session import Session

    from types_boto3_route53_recovery_cluster.client import Route53RecoveryClusterClient
    from types_boto3_route53_recovery_cluster.paginator import (
        ListRoutingControlsPaginator,
    )

    session = Session()
    client: Route53RecoveryClusterClient = session.client("route53-recovery-cluster")

    list_routing_controls_paginator: ListRoutingControlsPaginator = client.get_paginator("list_routing_controls")
    ```

Copyright 2024 Vlad Emelianov
"""

import sys
from typing import Generic, Iterator, TypeVar

from botocore.paginate import PageIterator, Paginator

from .type_defs import (
    ListRoutingControlsRequestListRoutingControlsPaginateTypeDef,
    ListRoutingControlsResponseTypeDef,
)

if sys.version_info >= (3, 12):
    from typing import Unpack
else:
    from typing_extensions import Unpack


__all__ = ("ListRoutingControlsPaginator",)


_ItemTypeDef = TypeVar("_ItemTypeDef")


class _PageIterator(PageIterator, Generic[_ItemTypeDef]):
    def __iter__(self) -> Iterator[_ItemTypeDef]:
        """
        Proxy method to specify iterator item type.
        """


class ListRoutingControlsPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/route53-recovery-cluster/paginator/ListRoutingControls.html#Route53RecoveryCluster.Paginator.ListRoutingControls)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_route53_recovery_cluster/paginators/#listroutingcontrolspaginator)
    """

    def paginate(
        self, **kwargs: Unpack[ListRoutingControlsRequestListRoutingControlsPaginateTypeDef]
    ) -> _PageIterator[ListRoutingControlsResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/route53-recovery-cluster/paginator/ListRoutingControls.html#Route53RecoveryCluster.Paginator.ListRoutingControls.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_route53_recovery_cluster/paginators/#listroutingcontrolspaginator)
        """

==> types_boto3_full-1.35.91-py3-none-any.whl: types_boto3_route53_recovery_cluster/paginator.py <==
"""
Type annotations for route53-recovery-cluster service client paginators.

[Documentation](https://youtype.github.io/types_boto3_docs/types_boto3_route53_recovery_cluster/paginators/)

Usage::

    ```python
    from boto3.session import Session

    from types_boto3_route53_recovery_cluster.client import Route53RecoveryClusterClient
    from types_boto3_route53_recovery_cluster.paginator import (
        ListRoutingControlsPaginator,
    )

    session = Session()
    client: Route53RecoveryClusterClient = session.client("route53-recovery-cluster")

    list_routing_controls_paginator: ListRoutingControlsPaginator = client.get_paginator("list_routing_controls")
    ```

Copyright 2025 Vlad Emelianov
"""

from __future__ import annotations

import sys
from typing import TYPE_CHECKING

from botocore.paginate import PageIterator, Paginator

from .type_defs import ListRoutingControlsRequestPaginateTypeDef, ListRoutingControlsResponseTypeDef

if sys.version_info >= (3, 12):
    from typing import Unpack
else:
    from typing_extensions import Unpack


__all__ = ("ListRoutingControlsPaginator",)


if TYPE_CHECKING:
    _ListRoutingControlsPaginatorBase = Paginator[ListRoutingControlsResponseTypeDef]
else:
    _ListRoutingControlsPaginatorBase = Paginator  # type: ignore[assignment]


class ListRoutingControlsPaginator(_ListRoutingControlsPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/route53-recovery-cluster/paginator/ListRoutingControls.html#Route53RecoveryCluster.Paginator.ListRoutingControls)
    [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_route53_recovery_cluster/paginators/#listroutingcontrolspaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListRoutingControlsRequestPaginateTypeDef]
    ) -> PageIterator[ListRoutingControlsResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/route53-recovery-cluster/paginator/ListRoutingControls.html#Route53RecoveryCluster.Paginator.ListRoutingControls.paginate)
        [Show types-boto3-full documentation](https://youtype.github.io/types_boto3_docs/types_boto3_route53_recovery_cluster/paginators/#listroutingcontrolspaginator)
        """
